@@ -1,23 +1,19 @@
 extern crate gcode;
 
 use std::env;
-use std::process;
 use std::error::Error as StdError;
 use std::fs::File;
-use std::io::{self, Read, Error, BufReader, BufRead};
+use std::io::{self, Error, Read};
+use std::process;
 
 fn run() -> Result<(), Error> {
-    let input = parse_args()?;
+    let mut input = parse_args()?;
 
-    for line in BufReader::new(input).lines() {
-        match line {
-            Ok(line) => {
-                for code in gcode::parse(&line) {
-                    println!("{:#?}", code);
-                }
-            },
-            Err(e) => return Err(e),
-        }
+    let mut src = String::new();
+    input.read_to_string(&mut src)?;
+
+    for code in gcode::parse(&src) {
+        println!("{:#?}", code);
     }
 
     Ok(())
@@ -34,7 +30,6 @@ fn main() {
             cause = c.cause();
         }
     }
-
 }
 
 fn parse_args() -> Result<Box<Read>, Error> {
